@@ -3,4 +3,5 @@ from .sa_cpu import JijSASampler
 from .sqa_cpu import JijSQASampler
 from .hubo_cpu import JijHUBOSampler
 from .sa_gpu import JijGPUSASampler
-from .sqa_gpu import JijGPUSQASampler
+from .chimera_sa_gpu import JijChimeraGPUSASampler
+from .chimera_sqa_gpu import JijChimeraGPUSQASampler
