@@ -10,6 +10,7 @@ import numpy as np
 class JijSASampler(JijCloudSampler, JijModelingInterface):
     hardware = 'cpu'
     algorithm = 'SA'
+    algorithm_model = 'SAParaSearch'
 
     def sample(self, bqm,
                beta_min=None, beta_max=None,
@@ -47,7 +48,7 @@ class JijSASampler(JijCloudSampler, JijModelingInterface):
                     num_reads:int = 1,
                     num_sweeps:int = 100,
                     beta_min=None, beta_max=None,
-                    sync=False
+                    sync=True
                     ):
 
         return super().sample_model(
